package iXApp::Controller::Root;

use base 'Catalyst::Controller';

# Sorgt dafr, dass die Actions dieses Controllers
# direkt unterhalb von '/' erreichbar sind.
__PACKAGE__->config->{namespace} = '';

sub index : Private {
   my ($self, $c) = @_;
   # Alle DB-Objekte an den View bergeben.
   $c->stash->{entries} = [ $c->model->all ];
   # Template-Datei fr RenderView festlegen.
   $c->stash->{template} = 'index';
}

sub edit : Local {
   my ($self, $c, $id) = @_;
   # Eintrag anhand der ID finden und bergeben.
   $c->stash->{entry} = $c->model->find($id);
   # Eintrag zum editieren/hinzufgen anzeigen.
   $c->stash->{template} = 'edit';
}

sub do_edit : Local {
   my ($self, $c, $id) = @_;
   # Formulareingaben jetzt berprfen.
   $c->forward( 'check_input' );
   # DB-Eintrag aktualisieren oder hinzufgen.
   $c->model->update_or_create( {
      id    => $id,
      title => $c->form->valid->{title},
      body  => $c->form->valid->{body}
   } );
   $c->forward( 'index' );
}

sub check_input : Private {
   my ($self, $c, $id) = @_;
   # Prft, ob die Eingaben dem Profil entsprechen.
   $c->form( $c->model->result_class->profile );
   # Eingaben nicht OK? Dann nochmals editieren.
   $c->detach('edit', $id) unless $c->form->success;
}

# Lschen von Eintrgen inkl. Fehlerbehandlung
sub delete : Local {
   my ($self, $c, $id) = @_;
   my $item = $c->model->find($id)
      or $c->detach('error', ['Ungltiger Aufruf']);
   $item->delete;
   $c->forward( 'index' );
}

# Speichert eine Meldung im Stash und geht zum Index.
sub error : Private {
   my ($self, $c, $message) = @_;
   $c->stash->{message} = $message;
   $c->forward( 'index' );
}

# Action fr das AJAX-In-Place-Edit
sub update_field : Local {
   my ($self, $c, $id, $field) = @_;
   # kein Wert bergeben? Dann Standardwert annehmen.
   my $value = $c->request->param($field) || 'leer';
   # Zeile in der DB anhand ihrer ID finden...
   my $item = $c->model->find($id);
   # ...und mit dem neuen Wert aktualisieren.
   $item->update( { $field => $value } );
   # Hier nur den Wert zurcksenden,
   # da die Anzeige clientseitig erfolgt.
   $c->response->body( $value );
}

# Jetzt wird die Kontrolle an den View abgegeben.
sub end : ActionClass('RenderView') {
   # Standard ist UTF8. Wir nutzen aber ISO-8859-1.
   my ($self, $c) = @_;
   $c->response->content_type
      ('text/html; charset=iso-8859-1');
}

1;
