#!/usr/bin/perl -w

use strict;
use warnings;

use FindBin;
use lib "$FindBin::Bin/../lib";

use YAML qw/LoadFile/;

use Getopt::Long;
use Term::ReadKey;

require iXApp;

my %p;
GetOptions( \%p, 'force', 'add-drop-table', 'diag', 'verbose' );

my $schema = iXApp::Schema->connect
  (@{ iXApp->config->{'Model::Journal'}{connect_info} });

# keine Fehlermeldung, falls Tabelle nicht vorhanden
$schema->storage->dbh->{PrintError} = $p{diag} || 0;

# Tabelle entsprechend des Schemas anlegen
if ( $p{'add-drop-table'} ) {
  if ( not $p{force} ) {
	 print "All existing data will be destroyed. Are you sure? [y/N]";
    ReadMode('cbreak');
	 my $key = '';
    while ( not grep{ $key eq $_ } "y", "n", "\n", "\r"  ) {
		$key = lc( ReadKey(0) );
	 };
	 print "\n";
    ReadMode('normal');
	 die "Aborted\n"  unless $key eq 'y';
  }
  $schema->deploy({ add_drop_table => 1 });
} else {
  local $schema->storage->dbh->{RaiseError} = 1;
  eval{ $schema->deploy() };
  die <<ERR if $@;
Fatal error during deploy.
Most propable this database has been deployed before.
Use '--add-drop-table' to overwrite existing data.
ERR
}

# Beispiel-Eintrag anlegen
$schema->resultset('Entry')->create({
   title => 'Mein erster Eintrag!',
   body  => 'Herzlich willkommen im Catalyst-Blog.',
});
